@@ -54,14 +54,14 @@ go_file_opener_finalize (GObject *obj)
 }
 
 static gboolean
-go_file_opener_can_probe_real (GOFileOpener const *fo, FileProbeLevel pl)
+go_file_opener_can_probe_real (GOFileOpener const *fo, GOFileProbeLevel pl)
 {
 	return fo->probe_func != NULL;
 }
 
 static gboolean
 go_file_opener_probe_real (GOFileOpener const *fo, GsfInput *input,
-			   FileProbeLevel pl)
+			   GOFileProbeLevel pl)
 {
 	gboolean ret = FALSE;
 
@@ -74,7 +74,7 @@ go_file_opener_probe_real (GOFileOpener const *fo, GsfInput *input,
 
 static void
 go_file_opener_open_real (GOFileOpener const *fo, gchar const *opt_enc,
-			  IOContext *io_context,
+			  GOIOContext *io_context,
 			  gpointer FIXME_workbook_view,
 			  GsfInput *input)
 {
@@ -87,7 +87,7 @@ go_file_opener_open_real (GOFileOpener const *fo, gchar const *opt_enc,
 			fo->open_func (fo, io_context,
 				       FIXME_workbook_view, input);
 	} else
-		gnumeric_io_error_unknown (io_context);
+		go_io_error_unknown (io_context);
 }
 
 static void
@@ -164,7 +164,7 @@ go_file_opener_new (gchar const *id,
 {
 	GOFileOpener *fo;
 
-	fo = GO_FILE_OPENER (g_object_new (TYPE_GO_FILE_OPENER, NULL));
+	fo = GO_FILE_OPENER (g_object_new (GO_TYPE_FILE_OPENER, NULL));
 	go_file_opener_setup (fo, id, description, suffixes, mimes, FALSE,
 			      probe_func, open_func);
 
@@ -195,7 +195,7 @@ go_file_opener_new_with_enc (gchar const *id,
 {
         GOFileOpener *fo;
 
-        fo = GO_FILE_OPENER (g_object_new (TYPE_GO_FILE_OPENER, NULL));
+        fo = GO_FILE_OPENER (g_object_new (GO_TYPE_FILE_OPENER, NULL));
         go_file_opener_setup (fo, id, description, suffixes, mimes, TRUE,
 			      probe_func, (GOFileOpenerOpenFunc)open_func);
         return fo;
@@ -229,7 +229,7 @@ go_file_opener_is_encoding_dependent (GOFileOpener const *fo)
 }
 
 gboolean
-go_file_opener_can_probe (GOFileOpener const *fo, FileProbeLevel pl)
+go_file_opener_can_probe (GOFileOpener const *fo, GOFileProbeLevel pl)
 {
 	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), FALSE);
 
@@ -254,14 +254,14 @@ go_file_opener_get_mimes (GOFileOpener const *fo)
  * go_file_opener_probe:
  * @fo      : #GOFileOpener
  * @input   : #GsfInput
- * @pl	    : #FileProbeLevel
+ * @pl	    : #GOFileProbeLevel
  *
  * Checks if a given file is supported by the opener.
  *
  * Returns: %TRUE, if the opener can read given file and %FALSE otherwise.
  **/
 gboolean
-go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl)
+go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, GOFileProbeLevel pl)
 {
 	g_return_val_if_fail (GO_IS_FILE_OPENER (fo), FALSE);
 	g_return_val_if_fail (GSF_IS_INPUT (input), FALSE);
@@ -284,13 +284,13 @@ go_file_opener_probe (GOFileOpener const *fo, GsfInput *input, FileProbeLevel pl
  *
  * Reads content of @file_name file into workbook @wbv is attached to.
  * Results are reported using @io_context object, use
- * gnumeric_io_error_occurred to find out if operation was successful.
+ * go_io_error_occurred to find out if operation was successful.
  * The state of @wbv and its workbook is undefined if operation fails, you
  * should destroy them in that case.
  */
 void
 go_file_opener_open (GOFileOpener const *fo, gchar const *opt_enc,
-		     IOContext *io_context,
+		     GOIOContext *io_context,
 		     gpointer FIXME_workbook_view, GsfInput *input)
 {
 	g_return_if_fail (GO_IS_FILE_OPENER (fo));
@@ -312,8 +312,8 @@ go_file_saver_init (GOFileSaver *fs)
 	fs->mime_type = NULL;
 	fs->description = NULL;
 	fs->overwrite_files = TRUE;
-	fs->format_level = FILE_FL_NEW;
-	fs->save_scope = FILE_SAVE_WORKBOOK;
+	fs->format_level = GO_FILE_FL_NEW;
+	fs->save_scope = GO_FILE_SAVE_WORKBOOK;
 	fs->save_func = NULL;
 }
 
@@ -432,11 +432,11 @@ go_file_saver_get_property (GObject *object, guint property_id,
 }
 
 static void
-go_file_saver_save_real (GOFileSaver const *fs, IOContext *io_context,
+go_file_saver_save_real (GOFileSaver const *fs, GOIOContext *io_context,
 			 gconstpointer FIXME_workbook_view, GsfOutput *output)
 {
 	if (fs->save_func == NULL) {
-		gnumeric_io_error_unknown (io_context);
+		go_io_error_unknown (io_context);
 		return;
 	}
 
@@ -509,9 +509,9 @@ go_file_saver_class_init (GOFileSaverClass *klass)
 		 FS_PROP_FORMAT_LEVEL,
 		 g_param_spec_enum ("format-level",
 				    _("Format Level"),
-				    _(""),
+				    "?",
 				    GO_TYPE_FILE_SAVER_LEVEL,
-				    FILE_FL_NEW,
+				    GO_FILE_FL_NEW,
 				    GSF_PARAM_STATIC |
 				    G_PARAM_READWRITE));
 
@@ -522,7 +522,7 @@ go_file_saver_class_init (GOFileSaverClass *klass)
 				    _("Scope"),
 				    _("How much of a document is saved"),
 				    GO_TYPE_FILE_SAVER_SCOPE,
-				    FILE_SAVE_WORKBOOK,
+				    GO_FILE_SAVE_WORKBOOK,
 				    GSF_PARAM_STATIC |
 				    G_PARAM_READWRITE));
 
@@ -562,12 +562,12 @@ GOFileSaver *
 go_file_saver_new (gchar const *id,
 		   gchar const *extension,
 		   gchar const *description,
-		   FileFormatLevel level,
+		   GOFileFormatLevel level,
 		   GOFileSaverSaveFunc save_func)
 {
 	GOFileSaver *fs;
 
-	fs = GO_FILE_SAVER (g_object_new (TYPE_GO_FILE_SAVER,
+	fs = GO_FILE_SAVER (g_object_new (GO_TYPE_FILE_SAVER,
 					  "id", id,
 					  "extension", extension,
 					  "description", description,
@@ -579,18 +579,18 @@ go_file_saver_new (gchar const *id,
 }
 
 void
-go_file_saver_set_save_scope (GOFileSaver *fs, FileSaveScope scope)
+go_file_saver_set_save_scope (GOFileSaver *fs, GOFileSaveScope scope)
 {
 	g_return_if_fail (GO_IS_FILE_SAVER (fs));
-	g_return_if_fail (scope < FILE_SAVE_LAST);
+	g_return_if_fail (scope < GO_FILE_SAVE_LAST);
 
 	fs->save_scope = scope;
 }
 
-FileSaveScope
+GOFileSaveScope
 go_file_saver_get_save_scope (GOFileSaver const *fs)
 {
-	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), FILE_SAVE_WORKBOOK);
+	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), GO_FILE_SAVE_WORKBOOK);
 
 	return fs->save_scope;
 }
@@ -627,10 +627,10 @@ go_file_saver_get_description (GOFileSaver const *fs)
 	return fs->description;
 }
 
-FileFormatLevel
+GOFileFormatLevel
 go_file_saver_get_format_level (GOFileSaver const *fs)
 {
-	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), FILE_FL_NEW);
+	g_return_val_if_fail (GO_IS_FILE_SAVER (fs), GO_FILE_FL_NEW);
 
 	return fs->format_level;
 }
@@ -657,12 +657,12 @@ go_file_saver_set_export_options (GOFileSaver *fs,
  *
  * Saves @wbv and the workbook it is attached to into @output stream.
  * Results are reported using @io_context object, use
- * gnumeric_io_error_occurred to find out if operation was successful.
+ * go_io_error_occurred to find out if operation was successful.
  * It's possible that @file_name is created and contain some data if
  * operation fails, you should remove the file in that case.
  */
 void
-go_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
+go_file_saver_save (GOFileSaver const *fs, GOIOContext *io_context,
 		    gconstpointer FIXME_workbook_view,
 		    GsfOutput *output)
 {
@@ -683,7 +683,7 @@ go_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
 		if (!fs->overwrite_files &&
 		    file_name &&
 		    g_file_test (file_name, G_FILE_TEST_EXISTS)) {
-			ErrorInfo *save_error;
+			GOErrorInfo *save_error;
 			const char *msg = _("Saving over old files of this type is disabled for safety.");
 
 			if (!gsf_output_error (output))
@@ -691,11 +691,11 @@ go_file_saver_save (GOFileSaver const *fs, IOContext *io_context,
 
 			g_free (file_name);
 
-			save_error = error_info_new_str_with_details (
+			save_error = go_error_info_new_str_with_details (
 				msg,
-				error_info_new_str (
+				go_error_info_new_str (
 					_("You can turn this safety feature off by editing appropriate plugin.xml file.")));
-			gnumeric_io_error_info_set (io_context, save_error);
+			go_io_error_info_set (io_context, save_error);
 			return;
 		}
 
@@ -730,12 +730,12 @@ go_file_saver_level_get_type (void)
 	static GType etype = 0;
 	if (etype == 0) {
 		static GEnumValue values[] = {
-			{ FILE_FL_NONE, (char*)"GO_FILE_SAVER_LEVEL_NONE", (char*)"none" },
-			{ FILE_FL_WRITE_ONLY, (char*)"GO_FILE_SAVER_LEVEL_WRITE_ONLY", (char*)"write_only" },
-			{ FILE_FL_NEW, (char*)"GO_FILE_SAVER_LEVEL_NEW", (char*)"new" },
-			{ FILE_FL_MANUAL, (char*)"GO_FILE_SAVER_LEVEL_MANUAL", (char*)"manual" },
-			{ FILE_FL_MANUAL_REMEMBER, (char*)"GO_FILE_SAVER_LEVEL_MANUAL_REMEMBER", (char*)"manual_remember" },
-			{ FILE_FL_AUTO, (char*)"GO_FILE_SAVER_LEVEL_AUTO", (char*)"auto" },
+			{ GO_FILE_FL_NONE, (char*)"GO_FILE_SAVER_LEVEL_NONE", (char*)"none" },
+			{ GO_FILE_FL_WRITE_ONLY, (char*)"GO_FILE_SAVER_LEVEL_WRITE_ONLY", (char*)"write_only" },
+			{ GO_FILE_FL_NEW, (char*)"GO_FILE_SAVER_LEVEL_NEW", (char*)"new" },
+			{ GO_FILE_FL_MANUAL, (char*)"GO_FILE_SAVER_LEVEL_MANUAL", (char*)"manual" },
+			{ GO_FILE_FL_MANUAL_REMEMBER, (char*)"GO_FILE_SAVER_LEVEL_MANUAL_REMEMBER", (char*)"manual_remember" },
+			{ GO_FILE_FL_AUTO, (char*)"GO_FILE_SAVER_LEVEL_AUTO", (char*)"auto" },
 			{ 0, NULL, NULL }
 		};
 		etype = g_enum_register_static ("GOFileSaverLevel", values);
@@ -749,9 +749,9 @@ go_file_saver_scope_get_type (void)
 	static GType etype = 0;
 	if (etype == 0) {
 		static GEnumValue values[] = {
-			{ FILE_SAVE_WORKBOOK, (char*)"GO_FILE_SAVER_SCOPE_WORKBOOK", (char*)"workbook" },
-			{ FILE_SAVE_SHEET, (char*)"GO_FILE_SAVER_SCOPE_SHEET", (char*)"sheet" },
-			{ FILE_SAVE_RANGE, (char*)"GO_FILE_SAVER_SCOPE_RANGE", (char*)"range" },
+			{ GO_FILE_SAVE_WORKBOOK, (char*)"GO_FILE_SAVER_SCOPE_WORKBOOK", (char*)"workbook" },
+			{ GO_FILE_SAVE_SHEET, (char*)"GO_FILE_SAVER_SCOPE_SHEET", (char*)"sheet" },
+			{ GO_FILE_SAVE_RANGE, (char*)"GO_FILE_SAVER_SCOPE_RANGE", (char*)"range" },
 			{ 0, NULL, NULL }
 		};
 		etype = g_enum_register_static ("GOFileSaverScope", values);
