@@ -23,7 +23,6 @@
 #include <goffice/goffice-config.h>
 #include <goffice/app/goffice-app.h>
 #include <goffice/app/go-doc-impl.h>
-#include <goffice/utils/go-glib-extras.h>
 
 #include <gsf/gsf-doc-meta-data.h>
 #include <gsf/gsf-impl-utils.h>
@@ -179,7 +178,6 @@ go_doc_set_uri (GODoc *doc, char const *uri)
 	char *new_uri;
 
 	g_return_val_if_fail (doc != NULL, FALSE);
-	g_return_val_if_fail (uri != NULL, FALSE);
 
 	if (go_str_compare (uri, doc->uri) == 0)
 		return TRUE;
