@@ -46,7 +46,7 @@ god_drawing_renderer_gdk_new (void)
 {
 	GodDrawingRendererGdk *renderer;
 
-	renderer = g_object_new (GOD_DRAWING_RENDERER_GDK_TYPE, NULL);
+	renderer = g_object_new (GOD_TYPE_DRAWING_RENDERER_GDK, NULL);
 
 	return renderer;
 }
@@ -174,7 +174,7 @@ get_pixbuf (GodDrawingRendererGdk *renderer,
 typedef struct {
 	GodDrawingRendererGdk *renderer;
 	GdkRectangle *rect;
-	long long y_ofs;
+	gint64 y_ofs;
 	const GodDefaultAttributes *default_attributes;
 } DrawTextContext;
 
@@ -185,7 +185,7 @@ make_absolute (PangoAttribute *attr, gpointer user_data)
 	if (attr->klass->type == PANGO_ATTR_SIZE &&
 	    ! ((PangoAttrSize *) attr)->absolute) {
 		PangoAttrSize *size_attr = (PangoAttrSize *) attr;
-		size_attr->size = GO_PT_TO_UN ((long long) size_attr->size) / draw_context->renderer->priv->y_units_per_pixel;
+		size_attr->size = GO_PT_TO_UN ((gint64) size_attr->size) / draw_context->renderer->priv->y_units_per_pixel;
 		size_attr->absolute = TRUE;
 	}
 	return FALSE;
