@@ -20,25 +20,10 @@
  */
 
 #include <goffice/goffice-config.h>
-
-#include <goffice/graph/gog-axis-line-impl.h>
-#include <goffice/graph/gog-axis.h>
-#include <goffice/graph/gog-chart.h>
-#include <goffice/graph/gog-chart-map.h>
-#include <goffice/graph/gog-chart-map-3d.h>
-#include <goffice/graph/gog-data-allocator.h>
-#include <goffice/graph/gog-renderer.h>
-#include <goffice/utils/go-style.h>
-#include <goffice/graph/gog-theme.h>
-#include <goffice/math/go-math.h>
-#include <goffice/utils/go-persist.h>
+#include <goffice/goffice.h>
 
 #include <gsf/gsf-impl-utils.h>
 
-#ifdef GOFFICE_WITH_GTK
-#include <goffice/gtk/goffice-gtk.h>
-#endif
-
 #include <glib/gi18n-lib.h>
 #include <string.h>
 
@@ -391,7 +376,7 @@ gog_axis_base_get_clamped_position (GogAxisBase *axis_base)
 #ifdef GOFFICE_WITH_GTK
 typedef struct {
 	GogAxisBase 	*axis_base;
-	GladeXML 	*gui;
+	GtkBuilder 	*gui;
 } AxisBasePrefs;
 
 static void
@@ -405,7 +390,7 @@ static void
 cb_cross_location_changed (GtkWidget *editor, AxisBasePrefs *state)
 {
 	gtk_toggle_button_set_active
-		(GTK_TOGGLE_BUTTON (glade_xml_get_widget (state->gui, "axis_cross")),
+		(GTK_TOGGLE_BUTTON (gtk_builder_get_object (state->gui, "axis_cross")),
 		 TRUE);
 }
 
@@ -422,7 +407,7 @@ cb_cross_axis_changed (GtkComboBox *combo, AxisBasePrefs *state)
 	state->axis_base->crossed_axis_id = g_value_get_uint (&value);
 
 	gtk_toggle_button_set_active
-		(GTK_TOGGLE_BUTTON (glade_xml_get_widget (state->gui, "axis_cross")),
+		(GTK_TOGGLE_BUTTON (gtk_builder_get_object (state->gui, "axis_cross")),
 		 TRUE);
 
 	g_value_unset (&value);
@@ -447,7 +432,7 @@ cb_position_toggled (GtkWidget *button, AxisBasePrefs *state)
 		position = GOG_AXIS_AT_LOW;
 
 	if (position != axis_base->position)
-		gtk_widget_set_sensitive (glade_xml_get_widget (state->gui, "padding_spinbutton"),
+		gtk_widget_set_sensitive (go_gtk_builder_get_widget (state->gui, "padding_spinbutton"),
 					  position != GOG_AXIS_CROSS);
 
 	if (position != GOG_AXIS_CROSS) {
@@ -494,26 +479,18 @@ gog_axis_base_populate_editor (GogObject *gobj,
 			       GogDataAllocator *dalloc,
 			       GOCmdContext *cc)
 {
-	static char const *toggle_props[] = {
+	static char const * const toggle_props[] = {
 		"major-tick-labeled",
 		"major-tick-out",
 		"major-tick-in",
 		"minor-tick-out",
 		"minor-tick-in"
 	};
-	GogAxis *crossed_axis;
 	GogAxisBase *axis_base;
-	GladeXML *gui;
-	GtkListStore *store;
-	GtkTreeIter iter;
-	GtkWidget *combo, *data_editor, *container, *w;
-	GtkCellRenderer *cell;
-	GSList *axes, *ptr;
-	AxisBasePrefs *state;
+	GtkBuilder *gui;
+	GtkWidget *w;
 	GogAxisType crossed_axis_type, axis_type;
 	static guint axis_base_pref_page = 0;
-	unsigned axis_count;
-	unsigned crossed_axis_id;
 	unsigned i;
 	gboolean hide_position_box = TRUE;
 
@@ -530,7 +507,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		return;
 	}
 
-	gui = go_glade_new ("gog-axis-prefs.glade", "axis_base_pref_box", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_new ("gog-axis-prefs.ui", GETTEXT_PACKAGE, cc);
 	if (gui == NULL) {
 		(GOG_OBJECT_CLASS(gab_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 		return;
@@ -539,8 +516,16 @@ gog_axis_base_populate_editor (GogObject *gobj,
 	crossed_axis_type = gog_axis_base_get_crossed_axis_type (axis_base);
 	if (crossed_axis_type != GOG_AXIS_UNKNOWN &&
 	    axis_type != GOG_AXIS_CIRCULAR) {
+		GtkListStore *store;
+		GogDataEditor *deditor;
+		GtkWidget *combo, *container, *w;
+		GSList *axes, *ptr;
+		unsigned axis_count;
+		GtkCellRenderer *cell;
+		AxisBasePrefs *state;
+		    
 		store = gtk_list_store_new (2, G_TYPE_STRING, G_TYPE_UINT);
-		combo = glade_xml_get_widget (gui, "cross_axis_combo");
+		combo = go_gtk_builder_get_widget (gui, "cross_axis_combo");
 		gtk_combo_box_set_model (GTK_COMBO_BOX (combo), GTK_TREE_MODEL (store));
 
 		cell = gtk_cell_renderer_text_new ();
@@ -552,6 +537,10 @@ gog_axis_base_populate_editor (GogObject *gobj,
 		axes = gog_chart_get_axes (axis_base->chart, crossed_axis_type);
 		axis_count = 0;
 		for (ptr = axes; ptr != NULL; ptr = ptr->next) {
+			GtkTreeIter iter;
+			GogAxis *crossed_axis;
+			unsigned crossed_axis_id;
+
 			crossed_axis = GOG_AXIS (ptr->data);
 			crossed_axis_id = gog_object_get_id (GOG_OBJECT (crossed_axis));
 			gtk_list_store_prepend (store, &iter);
@@ -567,33 +556,33 @@ gog_axis_base_populate_editor (GogObject *gobj,
 			gtk_widget_set_sensitive (GTK_WIDGET (combo), FALSE);
 		g_slist_free (axes);
 
-		data_editor = gog_data_allocator_editor (dalloc, GOG_DATASET (axis_base),
-							 GOG_AXIS_ELEM_CROSS_POINT, GOG_DATA_SCALAR);
-		container = glade_xml_get_widget (gui, "cross_location_alignment");
-		gtk_container_add (GTK_CONTAINER (container), data_editor);
+		deditor = gog_data_allocator_editor
+			(dalloc, GOG_DATASET (axis_base),
+			 GOG_AXIS_ELEM_CROSS_POINT, GOG_DATA_SCALAR);
+		container = go_gtk_builder_get_widget (gui, "cross_location_alignment");
+		gtk_container_add (GTK_CONTAINER (container), GTK_WIDGET (deditor));
 		gtk_widget_show_all (container);
 
 		state = g_new (AxisBasePrefs, 1);
 		state->axis_base = axis_base;
-		state->gui = gui;
+		state->gui = g_object_ref (gui);
 		g_signal_connect (G_OBJECT (combo), "changed",
 				  G_CALLBACK (cb_cross_axis_changed), state);
-		g_signal_connect (G_OBJECT (data_editor), "changed",
+		g_signal_connect (G_OBJECT (deditor), "changed",
 				  G_CALLBACK (cb_cross_location_changed), state);
-		g_object_set_data_full (G_OBJECT (combo),
-					"state", state, (GDestroyNotify) axis_base_pref_free);
+		g_signal_connect_swapped (G_OBJECT (combo), "destroy", G_CALLBACK (axis_base_pref_free), state);  
 
-		w = glade_xml_get_widget (gui, "axis_low");
+		w = go_gtk_builder_get_widget (gui, "axis_low");
 		if (axis_base->position == GOG_AXIS_AT_LOW)
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
 		g_signal_connect (G_OBJECT (w), "toggled",
 				  G_CALLBACK (cb_position_toggled), state);
-		w = glade_xml_get_widget (gui, "axis_cross");
+		w = go_gtk_builder_get_widget (gui, "axis_cross");
 		if (axis_base->position == GOG_AXIS_CROSS)
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
 		g_signal_connect (G_OBJECT (w), "toggled",
 				  G_CALLBACK (cb_position_toggled), state);
-		w = glade_xml_get_widget (gui, "axis_high");
+		w = go_gtk_builder_get_widget (gui, "axis_high");
 		if (axis_base->position == GOG_AXIS_AT_HIGH)
 			gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), TRUE);
 		g_signal_connect (G_OBJECT (w), "toggled",
@@ -601,7 +590,7 @@ gog_axis_base_populate_editor (GogObject *gobj,
 
 		hide_position_box = FALSE;
 	} else {
-		w = glade_xml_get_widget (gui, "cross_box");
+		w = go_gtk_builder_get_widget (gui, "cross_box");
 		gtk_widget_hide (w);
 	}
 
@@ -609,26 +598,26 @@ gog_axis_base_populate_editor (GogObject *gobj,
 	    axis_type == GOG_AXIS_Y ||
 	    axis_type == GOG_AXIS_Z ||
 	    axis_type == GOG_AXIS_RADIAL) {
-		w = glade_xml_get_widget (gui, "padding_spinbutton");
+		w = go_gtk_builder_get_widget (gui, "padding_spinbutton");
 		gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), axis_base->padding);
 		g_signal_connect (G_CALLBACK (w), "value-changed",
 				  G_CALLBACK (cb_padding_changed), axis_base);
 		gtk_widget_set_sensitive (w, axis_base->position != GOG_AXIS_CROSS);
 		hide_position_box = FALSE;
 	} else {
-		w = glade_xml_get_widget (gui, "padding_box");
+		w = go_gtk_builder_get_widget (gui, "padding_box");
 		gtk_widget_hide (w);
 	}
 
 	if (hide_position_box) {
-		w = glade_xml_get_widget (gui, "position_box");
+		w = go_gtk_builder_get_widget (gui, "position_box");
 		gtk_widget_hide (w);
 	}
 
 	for (i = 0; i < G_N_ELEMENTS (toggle_props) ; i++) {
 		gboolean cur_val;
 
-		w = glade_xml_get_widget (gui, toggle_props[i]);
+		w = go_gtk_builder_get_widget (gui, toggle_props[i]);
 		g_object_get (G_OBJECT (gobj), toggle_props[i], &cur_val, NULL);
 		gtk_toggle_button_set_active (GTK_TOGGLE_BUTTON (w), cur_val);
 		g_signal_connect_object (G_OBJECT (w),
@@ -638,13 +627,14 @@ gog_axis_base_populate_editor (GogObject *gobj,
 
 	if (gog_axis_is_discrete (axis_base->axis)) {
 		/* Hide minor tick properties */
-		GtkWidget *w = glade_xml_get_widget (gui, "minor_tick_box");
+		GtkWidget *w = go_gtk_builder_get_widget (gui, "minor_tick_box");
 		gtk_widget_hide (w);
 	}
 
 	go_editor_add_page (editor,
-			     glade_xml_get_widget (gui, "axis_base_pref_box"),
+			     go_gtk_builder_get_widget (gui, "axis_base_pref_box"),
 			     _("Layout"));
+	g_object_unref (gui);
 
 	(GOG_OBJECT_CLASS(gab_parent_klass)->populate_editor) (gobj, editor, dalloc, cc);
 }
@@ -655,7 +645,7 @@ gog_axis_base_init_style (GogStyledObject *gso, GOStyle *style)
 {
 	style->interesting_fields = GO_STYLE_LINE | GO_STYLE_FONT;
 	gog_theme_fillin_style (gog_object_get_theme (GOG_OBJECT (gso)),
-		style, GOG_OBJECT (gso), 0, FALSE);
+		style, GOG_OBJECT (gso), 0, GO_STYLE_LINE | GO_STYLE_FONT);
 }
 
 static void
@@ -1102,7 +1092,8 @@ axis_line_render (GogAxisBase *axis_base,
 		  GOGeometrySide side,
 		  double start_at,
 		  gboolean draw_labels,
-		  gboolean sharp)
+		  gboolean sharp,
+		  double *ticks_pos)
 {
 	GogAxisMap *map = NULL;
 	GogAxisTick *ticks;
@@ -1190,9 +1181,14 @@ axis_line_render (GogAxisBase *axis_base,
 		if (gog_axis_map (map, ticks[i].position) < start_at)
 			continue;
 
-		pos = gog_axis_map_to_view (map, ticks[i].position);
-		pos_x = x + pos * cos (axis_angle);
-		pos_y = y + pos * sin (axis_angle);
+		if (ticks_pos) {
+			pos_x = ticks_pos[2 * i];
+			pos_y = ticks_pos[2 * i + 1];
+		} else {
+			pos = gog_axis_map_to_view (map, ticks[i].position);
+			pos_x = x + pos * cos (axis_angle);
+			pos_y = y + pos * sin (axis_angle);
+		}
 
 		if (is_line_visible) {
 			switch (ticks[i].type) {
@@ -1221,12 +1217,17 @@ axis_line_render (GogAxisBase *axis_base,
 
 		if (ticks[i].label != NULL && draw_labels) {
 			GOGeometryOBR *obr = obrs + i;
-			pos = gog_axis_map_to_view (map, ticks[i].position);
 			obr->w += label_padding;
 			go_geometry_calc_label_position (obr, axis_angle, tick_len,
 							 side, label_anchor);
-			obr->x += x + pos * cos (axis_angle);
-			obr->y += y + pos * sin (axis_angle);
+			if (ticks_pos) {
+				obr->x += ticks_pos[2 * i];
+				obr->y += ticks_pos[2 * i + 1];
+			} else {
+				pos = gog_axis_map_to_view (map, ticks[i].position);
+				obr->x += x + pos * cos (axis_angle);
+				obr->y += y + pos * sin (axis_angle);
+			}
 
 			indexmap[nobr] = i;
 			nobr++;
@@ -1516,7 +1517,7 @@ x_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 			axis_line_render (axis_base, axis_base_view,
 					  view->renderer, ax, ay, bx - ax , by - ay, 
 					  GO_SIDE_RIGHT, -1.,
-					  axis_base->major_tick_labeled, TRUE);
+					  axis_base->major_tick_labeled, TRUE, NULL);
 			break;
 
 		case GOG_AXIS_BASE_PADDING_REQUEST:
@@ -1612,7 +1613,7 @@ xy_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 			axis_line_render (axis_base, axis_base_view,
 					  view->renderer, 
 					  ax, ay, bx - ax , by - ay, side, -1.,
-					  axis_base->major_tick_labeled, TRUE);
+					  axis_base->major_tick_labeled, TRUE, NULL);
 			break;
 
 		case GOG_AXIS_BASE_PADDING_REQUEST:
@@ -1692,7 +1693,7 @@ radar_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 								  parms->cx, parms->cy,
 								  bx - parms->cx, by - parms->cy,
 								  side, 0.1, i == parms->th0 && axis_base->major_tick_labeled,
-								  FALSE);
+								  FALSE, NULL);
 					} else {
 					       	gog_chart_map_2D_to_view (c_map, position, stop, &bx, &by);
 						axis_line_render (axis_base, axis_base_view,
@@ -1700,7 +1701,7 @@ radar_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 								  parms->cx, parms->cy,
 								  bx - parms->cx, by - parms->cy,
 								  side, 0., axis_base->major_tick_labeled,
-								  FALSE);
+								  FALSE, NULL);
 					}
 				break;
 			case GOG_AXIS_BASE_PADDING_REQUEST:
@@ -1793,6 +1794,7 @@ xyz_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 	double rx[8], ry[8], rz[8];
 	double major_tick_len, minor_tick_len, tick_len;
 	double label_w, label_h;
+	double *ticks_pos = NULL;
 
 	/* Note: Anti-clockwise order in each face,
 	 * important for calculating normals */
@@ -1918,6 +1920,17 @@ xyz_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 		                          &ax, &ay, NULL);
 		gog_chart_map_3d_to_view (c_map, xposition, yposition, stop,
 		                          &bx, &by, NULL);
+		if (action == GOG_AXIS_BASE_RENDER) {
+			tick_nbr = gog_axis_get_ticks (axis_base->axis, &ticks);
+			ticks_pos = g_new (double, 2 * tick_nbr);
+			for (i = 0; i < tick_nbr; i++)
+				gog_chart_map_3d_to_view (c_map, xposition,
+							  yposition,
+							  ticks[i].position,
+							  ticks_pos + 2 * i, 
+							  ticks_pos + 2 * i + 1,
+							  NULL);
+		}
 	} else if (axis_type == GOG_AXIS_X) {
 		yposition = *py[faces[base + vertex]];
 		zposition = *pz[faces[base + vertex]];
@@ -1928,6 +1941,18 @@ xyz_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 		                          &ax, &ay, NULL);
 		gog_chart_map_3d_to_view (c_map, stop, yposition, zposition,
 		                          &bx, &by, NULL);
+		if (action == GOG_AXIS_BASE_RENDER) {
+			tick_nbr = gog_axis_get_ticks (axis_base->axis, &ticks);
+			ticks_pos = g_new (double, 2 * tick_nbr);
+			for (i = 0; i < tick_nbr; i++) {
+				gog_chart_map_3d_to_view (c_map,
+							  ticks[i].position,
+							  yposition, zposition,
+							  ticks_pos + 2 * i, 
+							  ticks_pos + 2 * i + 1,
+							  NULL);
+			}
+		}
 	} else {
 		zposition = *pz[faces[base + vertex]];
 		xposition = *px[faces[base + vertex]];
@@ -1938,6 +1963,17 @@ xyz_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 		                          &ax, &ay, NULL);
 		gog_chart_map_3d_to_view (c_map, xposition, stop, zposition,
 		                          &bx, &by, NULL);
+		if (action == GOG_AXIS_BASE_RENDER) {
+			tick_nbr = gog_axis_get_ticks (axis_base->axis, &ticks);
+			ticks_pos = g_new (double, 2 * tick_nbr);
+			for (i = 0; i < tick_nbr; i++)
+				gog_chart_map_3d_to_view (c_map, xposition,
+							  ticks[i].position,
+							  zposition,
+							  ticks_pos + 2 * i, 
+							  ticks_pos + 2 * i + 1,
+							  NULL);
+		}
 	}
 
 	if (axis_type == perp_axis) {
@@ -1956,14 +1992,13 @@ xyz_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 	}
 	side = (tmp > 0)? GO_SIDE_LEFT : GO_SIDE_RIGHT;
 
-	gog_chart_map_3d_free (c_map);
-
 	switch (action) {
 		case GOG_AXIS_BASE_RENDER:
 			axis_line_render (axis_base, axis_base_view,
 					  view->renderer, 
 					  ax, ay, bx - ax , by - ay, side, -1.,
-					  axis_base->major_tick_labeled, TRUE);
+					  axis_base->major_tick_labeled, TRUE,
+					  ticks_pos);
 			break;
 		case GOG_AXIS_BASE_PADDING_REQUEST:
 			axis_line_bbox = axis_line_get_bbox (axis_base,
@@ -2037,6 +2072,8 @@ xyz_process (GogAxisBaseAction action, GogView *view, GogViewPadding *padding,
 			break;
 	}
 
+	gog_chart_map_3d_free (c_map);
+
 	return FALSE;
 }
 
