@@ -20,26 +20,13 @@
  * USA
  */
 
-#include "gog-child-button.h"
-
-#include <goffice/graph/gog-chart.h>
-#include <goffice/graph/gog-graph.h>
-#include <goffice/graph/gog-plot-engine.h>
-#include <goffice/graph/gog-plot.h>
-#include <goffice/graph/gog-trend-line.h>
-#include <goffice/gtk/goffice-gtk.h>
-#include <goffice/gtk/go-pixbuf.h>
 #include <goffice/goffice-config.h>
-
-#include <gtk/gtkmenu.h>
-#include <gtk/gtkimagemenuitem.h>
-#include <gtk/gtktogglebutton.h>
+#include <goffice/goffice.h>
 
 #include <gdk/gdkpixbuf.h>
 #include <gdk/gdkkeysyms.h>
 
 #include <glib/gi18n-lib.h>
-#include <glib/ghash.h>
 
 #include <string.h>
 
@@ -192,7 +179,7 @@ build_addition_process_childs (GogObject *object, BuildAdditionData *closure)
 			addition->parent = NULL;
 	}
 
-	if (!IS_GOG_GRAPH (object))
+	if (!GOG_IS_GRAPH (object))
 		for (child_iter = object->children; child_iter != NULL; child_iter = child_iter->next)
 				build_addition_process_childs (child_iter->data, closure);
 }
@@ -230,8 +217,8 @@ gog_child_button_build_additions (GogChildButton *child_button)
 	closure.child_button = child_button;
 
 	for (start_object = child_button->object;
-		  !IS_GOG_CHART (start_object) &&
-		  !IS_GOG_GRAPH (start_object) &&
+		  !GOG_IS_CHART (start_object) &&
+		  !GOG_IS_GRAPH (start_object) &&
 		  start_object != NULL;
 		  start_object = start_object->parent);
 
@@ -262,18 +249,17 @@ gog_child_button_free_additions (GogChildButton *child_button)
 /**
  * gog_child_button_set_object:
  * @child_button: a #GogChildButton
- * @object: a #GogObject
+ * @gog_object: a #GogObject
  *
  * Sets the current object with which @child_button operates.
  */
-
 void
-gog_child_button_set_object (GogChildButton *child_button, GogObject *object)
+gog_child_button_set_object (GogChildButton *child_button, GogObject *gog_object)
 {
 	g_return_if_fail (GOG_IS_CHILD_BUTTON (child_button));
-	g_return_if_fail (IS_GOG_OBJECT (object));
+	g_return_if_fail (GOG_IS_OBJECT (gog_object));
 
-	if (object == child_button->object)
+	if (gog_object == child_button->object)
 		return;
 
 	gog_child_button_free_additions (child_button);
@@ -287,8 +273,8 @@ gog_child_button_set_object (GogChildButton *child_button, GogObject *object)
 		child_button->object = NULL;
 	}
 
-	g_object_weak_ref (G_OBJECT (object), (GWeakNotify) gog_child_button_weak_notify, child_button);
-	child_button->object = object;
+	g_object_weak_ref (G_OBJECT (gog_object), (GWeakNotify) gog_child_button_weak_notify, child_button);
+	child_button->object = gog_object;
 	gog_child_button_build_additions (child_button);
 
 	gtk_widget_set_sensitive (GTK_WIDGET (child_button), child_button->additions != NULL);
