@@ -25,13 +25,14 @@
 #include "gog-plot-impl.h"
 #include "gog-object-xml.h"
 #include "gog-data-allocator.h"
-#include "gog-style.h"
 #include "gog-renderer.h"
 #include <goffice/data/go-data-impl.h>
 #include <goffice/data/go-data.h>
 #include <goffice/math/go-math.h>
 #include <goffice/utils/go-path.h>
 #include <goffice/utils/go-persist.h>
+#include <goffice/utils/go-style.h>
+#include <goffice/utils/go-libxml-extras.h>
 #include <gsf/gsf-impl-utils.h>
 
 #include <glib/gi18n-lib.h>
@@ -46,14 +47,6 @@ static GObjectClass *error_bar_parent_klass;
 #include <goffice/gtk/goffice-gtk.h>
 #include <goffice/gtk/go-pixbuf.h>
 #include <goffice/gtk/go-color-selector.h>
-#include <gtk/gtkspinbutton.h>
-#include <gtk/gtkcombobox.h>
-#include <gtk/gtkcellrendererpixbuf.h>
-#include <gtk/gtkcellrenderertext.h>
-#include <gtk/gtkcelllayout.h>
-#include <gtk/gtktable.h>
-#include <gtk/gtklabel.h>
-#include <glade/glade-xml.h>
 
 typedef struct {
 	GogSeries 	   *series;
@@ -141,7 +134,7 @@ cb_display_changed (GtkComboBox *combo, GogErrorBarEditor *editor)
 static void
 cb_type_changed (GtkWidget *w, GogErrorBarEditor *editor)
 {
-	GladeXML *gui = GLADE_XML (g_object_get_data (G_OBJECT (w), "gui"));
+	GtkBuilder *gui = GTK_BUILDER (g_object_get_data (G_OBJECT (w), "gui"));
 	gpointer data;
 	GogDataset *set;
 	GogDataAllocator *dalloc;
@@ -162,12 +155,12 @@ cb_type_changed (GtkWidget *w, GogErrorBarEditor *editor)
 			gtk_widget_destroy (GTK_WIDGET(data));
 		g_object_set_data (G_OBJECT (w), "plus", NULL);
 		g_object_set_data (G_OBJECT (w), "minus", NULL);
-		gtk_widget_hide (glade_xml_get_widget (gui, "values_box"));
-		gtk_widget_hide (glade_xml_get_widget (gui, "style_box"));
+		gtk_widget_hide (go_gtk_builder_get_widget (gui, "values_box"));
+		gtk_widget_hide (go_gtk_builder_get_widget (gui, "style_box"));
 	} else {
-		GtkWidget *table = glade_xml_get_widget (gui, "values_table");
+		GtkWidget *table = go_gtk_builder_get_widget (gui, "values_table");
 		if (!editor->bar) {
-			editor->bar = g_object_new (GOG_ERROR_BAR_TYPE, NULL);
+			editor->bar = g_object_new (GOG_TYPE_ERROR_BAR, NULL);
 			editor->bar->style->line.color = editor->color;
 			editor->bar->style->line.width = editor->line_width;
 			editor->bar->width = editor->width;
@@ -195,8 +188,8 @@ cb_type_changed (GtkWidget *w, GogErrorBarEditor *editor)
 			gtk_table_attach (GTK_TABLE (table), al, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 			g_object_set_data (G_OBJECT (w), "minus", al);
 		}
-		gtk_widget_show_all (glade_xml_get_widget (gui, "values_box"));
-		gtk_widget_show (glade_xml_get_widget (gui, "style_box"));
+		gtk_widget_show_all (go_gtk_builder_get_widget (gui, "values_box"));
+		gtk_widget_show (go_gtk_builder_get_widget (gui, "style_box"));
 	}
 	gog_object_request_update (GOG_OBJECT (editor->series));
 }
@@ -208,7 +201,7 @@ gog_error_bar_prefs (GogSeries *series,
 		     GogDataAllocator *dalloc,
 		     GOCmdContext *cc)
 {
-	GladeXML *gui;
+	GtkBuilder *gui;
 	GtkWidget *w, *bar_prefs;
 	GtkTable *style_table, *values_table;
 	GtkWidget *combo;
@@ -220,7 +213,7 @@ gog_error_bar_prefs (GogSeries *series,
 	GogErrorBarEditor *editor;
 	unsigned int i;
 
-	g_return_val_if_fail (IS_GOG_SERIES (series), NULL);
+	g_return_val_if_fail (GOG_IS_SERIES (series), NULL);
 
 	editor = g_new0 (GogErrorBarEditor, 1);
 	editor->series = series;
@@ -232,37 +225,37 @@ gog_error_bar_prefs (GogSeries *series,
 		editor->width = editor->bar->width;
 		editor->display = editor->bar->display;
 	} else {
-		editor->color = RGBA_BLACK;
+		editor->color = GO_COLOR_BLACK;
 		editor->line_width = 1.;
 		editor->width = 5.;
 		editor->display = GOG_ERROR_BAR_DISPLAY_BOTH;
 	}
 	set = GOG_DATASET (series);
 
-	gui = go_libglade_new ("gog-error-bar-prefs.glade", "gog_error_bar_prefs", GETTEXT_PACKAGE, cc);
+	gui = go_gtk_builder_new ("gog-error-bar-prefs.ui", GETTEXT_PACKAGE, cc);
 
 	/* Style properties */
 
 	/* Width */
-	w = glade_xml_get_widget (gui, "width");
+	w = go_gtk_builder_get_widget (gui, "width");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), editor->width);
 	g_signal_connect (gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (w)),
 		"value_changed",
 		G_CALLBACK (cb_width_changed), editor);
 	
 	/* Line width */
-	w = glade_xml_get_widget (gui, "line_width");
+	w = go_gtk_builder_get_widget (gui, "line_width");
 	gtk_spin_button_set_value (GTK_SPIN_BUTTON (w), editor->line_width);
 	g_signal_connect (gtk_spin_button_get_adjustment (GTK_SPIN_BUTTON (w)),
 		"value_changed",
 		G_CALLBACK (cb_line_width_changed), editor);
 
-	style_table = GTK_TABLE (glade_xml_get_widget (gui, "style_table"));
+	style_table = GTK_TABLE (gtk_builder_get_object (gui, "style_table"));
 
 	/* Color */
-	w = go_color_selector_new (editor->color, RGBA_BLACK, "error-bar");
+	w = go_color_selector_new (editor->color, GO_COLOR_BLACK, "error-bar");
 	gtk_label_set_mnemonic_widget (
-		GTK_LABEL (glade_xml_get_widget (gui, "color_label")), w);
+		GTK_LABEL (gtk_builder_get_object (gui, "color_label")), w);
 	g_signal_connect (G_OBJECT (w),
 		"activate",
 		G_CALLBACK (cb_color_changed), editor);
@@ -300,18 +293,19 @@ gog_error_bar_prefs (GogSeries *series,
 	g_signal_connect (G_OBJECT (combo), "changed", G_CALLBACK (cb_display_changed), editor);
 	
 	/* Category property*/
-	w = glade_xml_get_widget (gui, "category_combo");
+	w = go_gtk_builder_get_widget (gui, "category_combo");
 	gtk_combo_box_set_active (GTK_COMBO_BOX (w), (editor->bar)? (int) editor->bar->type: 0);
-	g_object_set_data_full (G_OBJECT (w), "gui", gui, (GDestroyNotify)g_object_unref);
+	g_object_set_data (G_OBJECT (w), "gui", gui);
 	g_object_set_data (G_OBJECT (w), "allocator", dalloc);
 	g_signal_connect (G_OBJECT (w), "changed", G_CALLBACK (cb_type_changed), editor);
 
 	/* Value properties */
-	bar_prefs = glade_xml_get_widget (gui, "gog_error_bar_prefs");
+	bar_prefs = go_gtk_builder_get_widget (gui, "gog_error_bar_prefs");
+	g_object_ref (bar_prefs);
 	g_signal_connect (bar_prefs, "destroy", G_CALLBACK (cb_destroy), editor);
 	gtk_widget_show_all (bar_prefs);
 
-	values_table = GTK_TABLE (glade_xml_get_widget (gui, "values_table"));
+	values_table = GTK_TABLE (gtk_builder_get_object (gui, "values_table"));
 	if (editor->bar) {
 		GtkWidget* al = GTK_WIDGET (gog_data_allocator_editor (dalloc, set, editor->bar->error_i, GOG_DATA_VECTOR));
 		gtk_widget_show (al);
@@ -322,9 +316,10 @@ gog_error_bar_prefs (GogSeries *series,
 		gtk_table_attach (values_table, al, 1, 2, 1, 2, GTK_FILL | GTK_EXPAND, 0, 0, 0);
 		g_object_set_data (G_OBJECT (w), "minus", al);
 	} else {
-		gtk_widget_hide (glade_xml_get_widget (gui, "values_box"));
-		gtk_widget_hide (glade_xml_get_widget (gui, "style_box"));
+		gtk_widget_hide (go_gtk_builder_get_widget (gui, "values_box"));
+		gtk_widget_hide (go_gtk_builder_get_widget (gui, "style_box"));
 	}
+	g_signal_connect (G_OBJECT (bar_prefs), "destroy", G_CALLBACK (g_object_unref), gui);
 
 	return GTK_WIDGET(bar_prefs);
 }
@@ -336,9 +331,9 @@ gog_error_bar_init (GogErrorBar* bar)
 	bar->type = GOG_ERROR_BAR_TYPE_NONE;
 	bar->display = GOG_ERROR_BAR_DISPLAY_BOTH;
 	bar->width = 5.;
-	bar->style = gog_style_new ();
-	bar->style->interesting_fields = GOG_STYLE_LINE;
-	bar->style->line.color = RGBA_BLACK;
+	bar->style = go_style_new ();
+	bar->style->interesting_fields = GO_STYLE_LINE;
+	bar->style->line.color = GO_COLOR_BLACK;
 	bar->style->line.width = 1.;
 }
 
@@ -435,7 +430,7 @@ gog_error_bar_persist_sax_save (GOPersist const *gp, GsfXMLOut *output)
 		gsf_xml_out_add_float (output, "width", bar->width, 6);
 	if (bar->style->line.width != 1.)
 		gsf_xml_out_add_float (output, "line_width", bar->style->line.width, 6);
-	if (bar->style->line.color != RGBA_BLACK)
+	if (bar->style->line.color != GO_COLOR_BLACK)
 		go_xml_out_add_color (output, "color", bar->style->line.color);
 }
 
@@ -483,7 +478,7 @@ gog_error_bar_persist_init (GOPersistClass *iface)
 GSF_CLASS_FULL (GogErrorBar, gog_error_bar,
 		NULL, NULL, gog_error_bar_class_init, NULL,
 		gog_error_bar_init, G_TYPE_OBJECT, 0,
-		GSF_INTERFACE (gog_error_bar_persist_init, GO_PERSIST_TYPE))
+		GSF_INTERFACE (gog_error_bar_persist_init, GO_TYPE_PERSIST))
 
 
 /**
@@ -506,39 +501,39 @@ gog_error_bar_get_bounds (GogErrorBar const *bar, int index, double *min, double
 {
 	double value;
 	GOData *data;
-	GODataVector *vec;
+	GOData *vec;
 	int length;
 
 	/* -1 ensures that the bar will not be displayed if the error is not a correct one.
 		With a 0 value, it might be, because of rounding errors */
 	*min = *max = -1.;
 
-	g_return_val_if_fail (IS_GOG_ERROR_BAR (bar), FALSE);
+	g_return_val_if_fail (GOG_IS_ERROR_BAR (bar), FALSE);
 	if (!gog_series_is_valid (bar->series))
 		return FALSE;
-	vec = GO_DATA_VECTOR (bar->series->values[bar->dim_i].data);
-	if (vec == NULL)
+	vec = bar->series->values[bar->dim_i].data;
+	if (vec == NULL || index < 0)
 		return FALSE;
-	value = go_data_vector_get_value (vec, index);
+	value = go_data_get_vector_value (vec, index);
 	data = bar->series->values[bar->error_i].data;
-	length = (IS_GO_DATA (data)) ? go_data_vector_get_len (GO_DATA_VECTOR (data)) : 0;
+	length = (GO_IS_DATA (data)) ? go_data_get_vector_size (data) : 0;
 
 	if ((bar->type == GOG_ERROR_BAR_TYPE_NONE) || isnan (value) || !go_finite (value))
 		return FALSE;
 
 	if (length == 1)
-		*max = go_data_vector_get_value (GO_DATA_VECTOR (data), 0);
+		*max = go_data_get_vector_value (data, 0);
 	else if (length > index)
-		*max = go_data_vector_get_value (GO_DATA_VECTOR (data), index);
+		*max = go_data_get_vector_value (data, index);
 
 	data = bar->series->values[bar->error_i + 1].data;
-	length = (IS_GO_DATA (data))? go_data_vector_get_len (GO_DATA_VECTOR (data)): 0;
+	length = (GO_IS_DATA (data))? go_data_get_vector_size (data): 0;
 	if (length == 0)
 		*min = *max; /* use same values for + and - */
 	else if (length == 1)
-		*min = go_data_vector_get_value (GO_DATA_VECTOR (data), 0);
+		*min = go_data_get_vector_value (data, 0);
 	else if (length > index)
-		*min = go_data_vector_get_value (GO_DATA_VECTOR (data), index);
+		*min = go_data_get_vector_value (data, index);
 
 	if (isnan (*min) || !go_finite (*min) || (*min <= 0)) {
 		*min = -1.;
@@ -570,7 +565,7 @@ gog_error_bar_get_minmax (const GogErrorBar *bar, double *min, double *max)
 	int i, imax;
 	double tmp_min, tmp_max, plus, minus;
 	
-	g_return_if_fail (IS_GOG_ERROR_BAR (bar));
+	g_return_if_fail (GOG_IS_ERROR_BAR (bar));
 
 	if (!gog_series_is_valid (bar->series)) {
 		*min = DBL_MAX;
@@ -578,11 +573,11 @@ gog_error_bar_get_minmax (const GogErrorBar *bar, double *min, double *max)
 		return;
 	}
 
-	imax = go_data_vector_get_len (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data));
+	imax = go_data_get_vector_size (bar->series->values[bar->dim_i].data);
 	if (imax == 0)
 		return;
-	go_data_vector_get_minmax (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data), min, max);
-	values = go_data_vector_get_values (GO_DATA_VECTOR (bar->series->values[bar->dim_i].data));
+	go_data_get_bounds (bar->series->values[bar->dim_i].data, min, max);
+	values = go_data_get_values (bar->series->values[bar->dim_i].data);
 
 	for (i = 0; i < imax; i++) {
 		if  (gog_error_bar_get_bounds (bar, i, &minus, &plus)) {
@@ -601,9 +596,9 @@ gog_error_bar_dup		(GogErrorBar const *bar)
 {
 	GogErrorBar* dbar;
 
-	g_return_val_if_fail (IS_GOG_ERROR_BAR (bar), NULL);
+	g_return_val_if_fail (GOG_IS_ERROR_BAR (bar), NULL);
 
-	dbar = g_object_new (GOG_ERROR_BAR_TYPE, NULL);
+	dbar = g_object_new (GOG_TYPE_ERROR_BAR, NULL);
 	dbar->type = bar->type;
 	dbar->series = bar->series;
 	dbar->dim_i = bar->dim_i;
@@ -611,7 +606,7 @@ gog_error_bar_dup		(GogErrorBar const *bar)
 	dbar->display = bar->display;
 	dbar->width = bar->width;
 	if (dbar->style) g_object_unref (dbar->style);
-	dbar->style = gog_style_dup (bar->style);
+	dbar->style = go_style_dup (bar->style);
 	return dbar;
 }
 
