@@ -73,71 +73,71 @@ enum {
 };
 
 GONamedColor const default_color_set [] = {
-	{ RGBA_TO_UINT (0x00, 0x00, 0x00, 0xff), N_("black")},
-	{ RGBA_TO_UINT (0x99, 0x33, 0x00, 0xff), N_("light brown")},
-	{ RGBA_TO_UINT (0x33, 0x33, 0x00, 0xff), N_("brown gold")},
-	{ RGBA_TO_UINT (0x00, 0x33, 0x00, 0xff), N_("dark green #2")},
-	{ RGBA_TO_UINT (0x00, 0x33, 0x66, 0xff), N_("navy")},
-	{ RGBA_TO_UINT (0x00, 0x00, 0x80, 0xff), N_("dark blue")},
-	{ RGBA_TO_UINT (0x33, 0x33, 0x99, 0xff), N_("purple #2")},
-	{ RGBA_TO_UINT (0x33, 0x33, 0x33, 0xff), N_("very dark gray")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0x00, 0xff), N_("black")},
+	{ GO_COLOR_FROM_RGBA (0x99, 0x33, 0x00, 0xff), N_("light brown")},
+	{ GO_COLOR_FROM_RGBA (0x33, 0x33, 0x00, 0xff), N_("brown gold")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x33, 0x00, 0xff), N_("dark green #2")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x33, 0x66, 0xff), N_("navy")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0x80, 0xff), N_("dark blue")},
+	{ GO_COLOR_FROM_RGBA (0x33, 0x33, 0x99, 0xff), N_("purple #2")},
+	{ GO_COLOR_FROM_RGBA (0x33, 0x33, 0x33, 0xff), N_("very dark gray")},
 
-	{ RGBA_TO_UINT (0x80, 0x00, 0x00, 0xff), N_("dark red")},
-	{ RGBA_TO_UINT (0xFF, 0x66, 0x00, 0xff), N_("red-orange")},
-	{ RGBA_TO_UINT (0x80, 0x80, 0x00, 0xff), N_("gold")},
-	{ RGBA_TO_UINT (0x00, 0x80, 0x00, 0xff), N_("dark green")},
-	{ RGBA_TO_UINT (0x00, 0x80, 0x80, 0xff), N_("dull blue")},
-	{ RGBA_TO_UINT (0x00, 0x00, 0xFF, 0xff), N_("blue")},
-	{ RGBA_TO_UINT (0x66, 0x66, 0x99, 0xff), N_("dull purple")},
-	{ RGBA_TO_UINT (0x80, 0x80, 0x80, 0xff), N_("dark gray")},
+	{ GO_COLOR_FROM_RGBA (0x80, 0x00, 0x00, 0xff), N_("dark red")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0x66, 0x00, 0xff), N_("red-orange")},
+	{ GO_COLOR_FROM_RGBA (0x80, 0x80, 0x00, 0xff), N_("gold")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x80, 0x00, 0xff), N_("dark green")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x80, 0x80, 0xff), N_("dull blue")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0xFF, 0xff), N_("blue")},
+	{ GO_COLOR_FROM_RGBA (0x66, 0x66, 0x99, 0xff), N_("dull purple")},
+	{ GO_COLOR_FROM_RGBA (0x80, 0x80, 0x80, 0xff), N_("dark gray")},
 
-	{ RGBA_TO_UINT (0xFF, 0x00, 0x00, 0xff), N_("red")},
-	{ RGBA_TO_UINT (0xFF, 0x99, 0x00, 0xff), N_("orange")},
-	{ RGBA_TO_UINT (0x99, 0xCC, 0x00, 0xff), N_("lime")},
-	{ RGBA_TO_UINT (0x33, 0x99, 0x66, 0xff), N_("dull green")},
-	{ RGBA_TO_UINT (0x33, 0xCC, 0xCC, 0xff), N_("dull blue #2")},
-	{ RGBA_TO_UINT (0x33, 0x66, 0xFF, 0xff), N_("sky blue #2")},
-	{ RGBA_TO_UINT (0x80, 0x00, 0x80, 0xff), N_("purple")},
-	{ RGBA_TO_UINT (0x96, 0x96, 0x96, 0xff), N_("gray")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0x00, 0x00, 0xff), N_("red")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0x99, 0x00, 0xff), N_("orange")},
+	{ GO_COLOR_FROM_RGBA (0x99, 0xCC, 0x00, 0xff), N_("lime")},
+	{ GO_COLOR_FROM_RGBA (0x33, 0x99, 0x66, 0xff), N_("dull green")},
+	{ GO_COLOR_FROM_RGBA (0x33, 0xCC, 0xCC, 0xff), N_("dull blue #2")},
+	{ GO_COLOR_FROM_RGBA (0x33, 0x66, 0xFF, 0xff), N_("sky blue #2")},
+	{ GO_COLOR_FROM_RGBA (0x80, 0x00, 0x80, 0xff), N_("purple")},
+	{ GO_COLOR_FROM_RGBA (0x96, 0x96, 0x96, 0xff), N_("gray")},
 
-	{ RGBA_TO_UINT (0xFF, 0x00, 0xFF, 0xff), N_("magenta")},
-	{ RGBA_TO_UINT (0xFF, 0xCC, 0x00, 0xff), N_("bright orange")},
-	{ RGBA_TO_UINT (0xFF, 0xFF, 0x00, 0xff), N_("yellow")},
-	{ RGBA_TO_UINT (0x00, 0xFF, 0x00, 0xff), N_("green")},
-	{ RGBA_TO_UINT (0x00, 0xFF, 0xFF, 0xff), N_("cyan")},
-	{ RGBA_TO_UINT (0x00, 0xCC, 0xFF, 0xff), N_("bright blue")},
-	{ RGBA_TO_UINT (0x99, 0x33, 0x66, 0xff), N_("red purple")},
-	{ RGBA_TO_UINT (0xC0, 0xC0, 0xC0, 0xff), N_("light gray")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0x00, 0xFF, 0xff), N_("magenta")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0xCC, 0x00, 0xff), N_("bright orange")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0x00, 0xff), N_("yellow")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0xFF, 0x00, 0xff), N_("green")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0xFF, 0xFF, 0xff), N_("cyan")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0xCC, 0xFF, 0xff), N_("bright blue")},
+	{ GO_COLOR_FROM_RGBA (0x99, 0x33, 0x66, 0xff), N_("red purple")},
+	{ GO_COLOR_FROM_RGBA (0xC0, 0xC0, 0xC0, 0xff), N_("light gray")},
 
-	{ RGBA_TO_UINT (0xFF, 0x99, 0xCC, 0xff), N_("pink")},
-	{ RGBA_TO_UINT (0xFF, 0xCC, 0x99, 0xff), N_("light orange")},
-	{ RGBA_TO_UINT (0xFF, 0xFF, 0x99, 0xff), N_("light yellow")},
-	{ RGBA_TO_UINT (0xCC, 0xFF, 0xCC, 0xff), N_("light green")},
-	{ RGBA_TO_UINT (0xCC, 0xFF, 0xFF, 0xff), N_("light cyan")},
-	{ RGBA_TO_UINT (0x99, 0xCC, 0xFF, 0xff), N_("light blue")},
-	{ RGBA_TO_UINT (0xCC, 0x99, 0xFF, 0xff), N_("light purple")},
-	{ RGBA_TO_UINT (0xFF, 0xFF, 0xFF, 0xff), N_("white")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0x99, 0xCC, 0xff), N_("pink")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0xCC, 0x99, 0xff), N_("light orange")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0x99, 0xff), N_("light yellow")},
+	{ GO_COLOR_FROM_RGBA (0xCC, 0xFF, 0xCC, 0xff), N_("light green")},
+	{ GO_COLOR_FROM_RGBA (0xCC, 0xFF, 0xFF, 0xff), N_("light cyan")},
+	{ GO_COLOR_FROM_RGBA (0x99, 0xCC, 0xFF, 0xff), N_("light blue")},
+	{ GO_COLOR_FROM_RGBA (0xCC, 0x99, 0xFF, 0xff), N_("light purple")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0xFF, 0xff), N_("white")},
 
 	{ 0, NULL},
 
 	/* Disable these for now, they are mostly repeats */
-	{ RGBA_TO_UINT (0x99, 0x99, 0xFF, 0xff), N_("purplish blue")},
-	{ RGBA_TO_UINT (0x99, 0x33, 0x66, 0xff), N_("red purple")},
-	{ RGBA_TO_UINT (0xFF, 0xFF, 0xCC, 0xff), N_("light yellow")},
-	{ RGBA_TO_UINT (0xCC, 0xFF, 0xFF, 0xff), N_("light blue")},
-	{ RGBA_TO_UINT (0x66, 0x00, 0x66, 0xff), N_("dark purple")},
-	{ RGBA_TO_UINT (0xFF, 0x80, 0x80, 0xff), N_("pink")},
-	{ RGBA_TO_UINT (0x00, 0x66, 0xCC, 0xff), N_("sky blue")},
-	{ RGBA_TO_UINT (0xCC, 0xCC, 0xFF, 0xff), N_("light purple")},
+	{ GO_COLOR_FROM_RGBA (0x99, 0x99, 0xFF, 0xff), N_("purplish blue")},
+	{ GO_COLOR_FROM_RGBA (0x99, 0x33, 0x66, 0xff), N_("red purple")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0xCC, 0xff), N_("light yellow")},
+	{ GO_COLOR_FROM_RGBA (0xCC, 0xFF, 0xFF, 0xff), N_("light blue")},
+	{ GO_COLOR_FROM_RGBA (0x66, 0x00, 0x66, 0xff), N_("dark purple")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0x80, 0x80, 0xff), N_("pink")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x66, 0xCC, 0xff), N_("sky blue")},
+	{ GO_COLOR_FROM_RGBA (0xCC, 0xCC, 0xFF, 0xff), N_("light purple")},
 
-	{ RGBA_TO_UINT (0x00, 0x00, 0x80, 0xff), N_("dark blue")},
-	{ RGBA_TO_UINT (0xFF, 0x00, 0xFF, 0xff), N_("magenta")},
-	{ RGBA_TO_UINT (0xFF, 0xFF, 0x00, 0xff), N_("yellow")},
-	{ RGBA_TO_UINT (0x00, 0xFF, 0xFF, 0xff), N_("cyan")},
-	{ RGBA_TO_UINT (0x80, 0x00, 0x80, 0xff), N_("purple")},
-	{ RGBA_TO_UINT (0x80, 0x00, 0x00, 0xff), N_("dark red")},
-	{ RGBA_TO_UINT (0x00, 0x80, 0x80, 0xff), N_("dull blue")},
-	{ RGBA_TO_UINT (0x00, 0x00, 0xFF, 0xff), N_("blue")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0x80, 0xff), N_("dark blue")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0x00, 0xFF, 0xff), N_("magenta")},
+	{ GO_COLOR_FROM_RGBA (0xFF, 0xFF, 0x00, 0xff), N_("yellow")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0xFF, 0xFF, 0xff), N_("cyan")},
+	{ GO_COLOR_FROM_RGBA (0x80, 0x00, 0x80, 0xff), N_("purple")},
+	{ GO_COLOR_FROM_RGBA (0x80, 0x00, 0x00, 0xff), N_("dark red")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x80, 0x80, 0xff), N_("dull blue")},
+	{ GO_COLOR_FROM_RGBA (0x00, 0x00, 0xFF, 0xff), N_("blue")},
 
 	{ 0, NULL},
 };
@@ -160,7 +160,7 @@ create_color_sel (GObject *action_proxy, GOColor c, GCallback handler, gboolean
 		go_color_to_gdk (c, &gdk));
 	gtk_color_selection_set_has_opacity_control (colorsel, allow_alpha);
 	if (allow_alpha)
-		gtk_color_selection_set_current_alpha (colorsel, UINT_RGBA_A(c) * 257);
+		gtk_color_selection_set_current_alpha (colorsel, GO_COLOR_UINT_A(c) * 257);
 
 	g_signal_connect_object (dialog,
 		"response", handler, action_proxy, 0);
@@ -179,9 +179,9 @@ handle_color_sel (GtkColorSelectionDialog *dialog,
 		guint16 alpha = gtk_color_selection_get_current_alpha (colorsel);
 
 		gtk_color_selection_get_current_color (colorsel, &gdk);
-		*res = GDK_TO_UINT (gdk);
+		*res = GO_COLOR_FROM_GDK (gdk);
 		alpha >>= 8;
-		*res = UINT_RGBA_CHANGE_A (*res, alpha);
+		*res = GO_COLOR_CHANGE_A (*res, alpha);
 	}
 	/* destroy _before_ we emit */
 	gtk_object_destroy (GTK_OBJECT (dialog));
@@ -295,7 +295,7 @@ swatch_activated (GOColorPalette *pal, GtkBin *button)
 
 	g_return_if_fail (swatch != NULL);
 
-	set_color (pal, GDK_TO_UINT (swatch->style->bg[GTK_STATE_NORMAL]),
+	set_color (pal, GO_COLOR_FROM_GDK (swatch->style->bg[GTK_STATE_NORMAL]),
 		   FALSE, TRUE, FALSE);
 }
 
