@@ -15,7 +15,7 @@
  *
  * You should have received a copy of the GNU General Public License
  * along with this program; if not, write to the Free Software
- * Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA 02111-1307
+ * Foundation, Inc., 51 Franklin St, Fifth Floor, Boston, MA  02110-1301
  * USA
  */
 
@@ -23,22 +23,35 @@
 #define GOG_LIN_REG_H
 
 #include <goffice/graph/gog-reg-curve.h>
+#include <goffice/math/go-regression.h>
 
 G_BEGIN_DECLS
 
-typedef struct {
-	GogRegCurve	base;
-
-	double a0, a1, R2;
-	char *equation;
+typedef  struct {
+	GogRegCurve base;
+	gboolean affine;
+	double **x_vals, *y_vals;
+	int dims;
 } GogLinRegCurve;
-typedef GogRegCurveClass GogLinRegCurveClass;
 
-#define GOG_LIN_REG_CURVE_TYPE	(gog_lin_reg_curve_get_type ())
-#define GOG_LIN_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_LIN_REG_CURVE_TYPE, GogLinRegCurve))
-#define GOG_IS_LIN_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_LIN_REG_CURVE_TYPE))
+typedef struct {
+	GogRegCurveClass base;
+
+	GORegressionResult (*lin_reg_func) (double **xss, int dim,
+				    const double *ys, int n,
+				    gboolean affine,
+				    double *res,
+				    go_regression_stat_t *stat);
+	int (*build_values) (GogLinRegCurve *rc, double const *x_vals,
+					double const *y_vals, int n);
+} GogLinRegCurveClass;
+
+#define GOG_TYPE_LIN_REG_CURVE	(gog_lin_reg_curve_get_type ())
+#define GOG_LIN_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_CAST ((o), GOG_TYPE_LIN_REG_CURVE, GogLinRegCurve))
+#define GOG_IS_LIN_REG_CURVE(o)	(G_TYPE_CHECK_INSTANCE_TYPE ((o), GOG_TYPE_LIN_REG_CURVE))
 
 GType gog_lin_reg_curve_get_type (void);
+void  gog_lin_reg_curve_register_type (GTypeModule *module);
 
 G_END_DECLS
 
